@@ -10,7 +10,6 @@ DayHistory::DayHistory(QWidget *parent) :
     lstExercises = new QListView();
     model = new QStandardItemModel(this);
     lstExercises->setModel(model);
-    lstExercises->setSelectionMode(QListView::NoSelection);
     setCentralWidget (lstExercises);
 }
 
@@ -18,7 +17,7 @@ DayHistory::DayHistory(QWidget *parent) :
 void DayHistory::load(QString date)
 {
     QList <QString> tmp;
-    QString name, group, reps, var;
+    QString name, group;
     setWindowTitle(date);
     model->clear();
     exercises = xml->getHistoryByDate(date);
@@ -28,13 +27,11 @@ void DayHistory::load(QString date)
         tmp = exercises.takeFirst();
         name = tmp.takeFirst();
         group = tmp.takeFirst();
-        var = tmp.takeFirst();
-        reps = tmp.takeFirst();
 
         if(group != "Cardio")
-            model->appendRow(new QStandardItem(group + "/" + name + ": " + var + "Kg - " + reps + " reps"));
+            model->appendRow(new QStandardItem(group + "/" + name ));
         else
-            model->appendRow(new QStandardItem(group + "/" + name + ": " + var + "Km - " + reps));
+            model->appendRow(new QStandardItem(group + "/" + name ));
     }
 
 }
