@@ -24,7 +24,6 @@ InfoWindow::InfoWindow(QWidget *parent) :
     lblName = new QLabel("name");
     lblMuscle = new QLabel("muscle");
     lblSet = new QLabel("set");
-    lblReps = new QLabel("reps");
     lblRest = new QLabel("rest");
     lblLast = new QLabel("last time");
     lblInfo = new QLabel("info on how to do");
@@ -36,7 +35,6 @@ InfoWindow::InfoWindow(QWidget *parent) :
     vLayout->addWidget(lblMuscle);
 
     hLabelLayout->addWidget(lblSet);
-    hLabelLayout->addWidget(lblReps);
     hLabelLayout->addWidget(lblRest);
     vLayout->addLayout(hLabelLayout);
 
@@ -185,9 +183,10 @@ void InfoWindow::changeEvent(QEvent *event)
 void InfoWindow::loadExercise(QString name)
 {
     QList <QString> list;
-    QString weight[3], status[3];
+    QString weight[9], reps[9];
     QString min, sec;
-    QString reps[3], currentReps;
+    int i = 0;
+    QString lastText;
 
     exerciseName = name;
 
@@ -197,57 +196,32 @@ void InfoWindow::loadExercise(QString name)
     lblMuscle->setText(list.takeFirst());
     info = list.takeFirst();
 
-    weight[0] = list.takeFirst();
-    weight[1] = list.takeFirst();
-    weight[2] = list.takeFirst();
-
-    status[0] = list.takeFirst();
-    status[1] = list.takeFirst();
-    status[2] = list.takeFirst();
-
     list = xml->loadSettings();
     if(list.isEmpty())
         return;
 
-    list.removeLast();
+    list.removeLast(); //remove calories
     sec = list.takeLast(); min = list.takeLast();
     lblRest->setText(min + ":" + sec + " rest");
 
-    currentReps = list.takeLast();
-    reps[2] = list.takeLast();
-    reps[1] = list.takeLast();
-    reps[0] = list.takeLast();
+    list = xml->getHistoryByExercise(exerciseName);
 
-
-    if(currentReps == "Low")
+    while(!list.isEmpty())
     {
-        if(weight[0] != "0")
-            lblLast->setText(weight[0] + "kg was " + status[0] + " last time.");
-        else
-            lblLast->setText("Exercise have never been done.");
-
-        lblReps->setText(reps[0] + " Reps");
+        weight[i] = list.takeFirst();
+        reps[i] = list.takeFirst();
+        list.removeFirst(); //remove status
+        i++;
     }
 
-    else if(currentReps == "Mid")
+    i = 0;
+    lastText = "";
+    while(weight[i] != "")
     {
-        if(weight[1] != "0")
-            lblLast->setText(weight[1] + "kg was " + status[1] + " last time.");
-        else
-            lblLast->setText("Exercise have never been done.");
-
-        lblReps->setText(reps[1] + " Reps");
+        lastText.append(weight[i] + "x" + reps[i]);
     }
 
-    else
-    {
-        if(weight[2] != "0")
-            lblLast->setText(weight[2] + "kg was " + status[2] + " last time.");
-        else
-            lblLast->setText("Exercise have never been done.");
-
-        lblReps->setText(reps[2] + " Reps");
-    }
+    lblLast->setText("Last time: " + lastText);
 
     lblSet->setText(list.takeLast() + " Set");
 
