@@ -116,11 +116,9 @@ void WeightDialog::save()
         reps = min + ":" + sec;
         xml->updateLastDistance(exName, weight, min, sec, status);
     }
-    else
-    {
-        xml->updateLastWeight(exName, weight, status, reps);
-    }
-    xml->saveDoneEx(group, exName, weight, reps);
+
+    xml->saveDoneEx(group, exName, weight, reps, status);
+
     this->hide();
     emit next();
 
