@@ -14,6 +14,9 @@ public:
     void load(QString name, QString grp, QString currentReps);
     void loadCardio(QString name, QString m, QString s);
 
+signals:
+    void next();
+
 private slots:
     void save();
 
